<?php
/**
 * An interface for a package assembler
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Assembler extends FrameworkInterface {
	/**
	 * Chunks the content from $packageContent and feeds it into another queue
	 * for verification and possible re-requesting.
	 *
	 * @param	$packageContent		An array with two elements: 'raw_data' and 'error_code'
	 * @return	void
	 */
	function chunkPackageContent (array $packageContent);

	/**
	 * Checks whether the assembler's pending data is empty which means it has
	 * no pending data left for handling ... ;-)
	 *
	 * @return	$ifPendingDataIsEmpty	Whether pending data is empty
	 */
	function isPendingDataEmpty ();

	/**
	 * Handles the assembler's pending data
	 *
	 * @return	void
	 */
	function handlePendingData ();

	/**
	 * Checks whether the assembler has multiple messages pending
	 *
	 * @return	$isPending	Whether the assembler has multiple messages pending
	 */
	function ifMultipleMessagesPending ();

	/**
	 * Handles multiple messages.
	 *
	 * @return	void
	 */
	function handleMultipleMessages ();
}

// [EOF]
?>
