<?php
/**
 * A DhtRecipient discovery class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DhtRecipientDiscovery extends BaseRecipientDiscovery implements DiscoverableDhtRecipient, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Create an instance of this class
	 *
	 * @return	$discoveryInstance	An instance of this discovery class
	 */
	public static final function createDhtRecipientDiscovery () {
		// Get an instance of this class
		$discoveryInstance = new DhtRecipientDiscovery();

		// Get a DHT instance
		$dhtInstance = DhtObjectFactory::createDhtInstance('node');

		// Set it here
		$discoveryInstance->setDhtInstance($dhtInstance);

		// Return the prepared instance
		return $discoveryInstance;
	}

	/**
	 * Resolves one or more recipients for a DHT transfer by given package data.
	 *
	 * @param	$packageData	Valid package data array
	 * @return	$recipients		An indexed array with DHT recipients
	 */
	public function resolveRecipientsByPackageData (array $packageData) {
		// Use facade to get recipients back
		$recipients = $this->getDhtInstance()->findRecipientsByPackageData($packageData);

		// Return it
		return $recipients;
	}
}

// [EOF]
?>
