<?php
/**
 * A RequestNodeListMessageAnswer node helper class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		Find an interface for hub helper
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class NodeRequestNodeListMessageAnswerHelper extends BaseHubAnswerHelper implements HelpableNode {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Init package tags
		$this->setPackageTags(array('request_node_list_answer'));
	}

	/**
	 * Creates the helper class
	 *
	 * @param	$messageData		An array with all message data
	 * @return	$helperInstance		A prepared instance of this helper
	 */
	public final static function createNodeRequestNodeListMessageAnswerHelper (array $messageData) {
		// Get new instance
		$helperInstance = new NodeRequestNodeListMessageAnswerHelper();

		// Set session id of other peer as recipient
		$helperInstance->setRecipientType($messageData[XmlRequestNodeListTemplateEngine::REQUEST_DATA_SESSION_ID]);

		// Set message data
		$helperInstance->setMessageData($messageData);

		// Return the prepared instance
		return $helperInstance;
	}

	/**
	 * Loads the descriptor XML file
	 *
	 * @param	$nodeInstance	An instance of a NodeHelper class
	 * @return	void
	 */
	public function loadDescriptorXml (NodeHelper $nodeInstance) {
		// Debug message
		self::createDebugInstance(__CLASS__)->debugOutput('HELPER[' . __METHOD__ . ':' . __LINE__ . ']: Attempting to answer a request: node-list...');

		// Get a XML template instance
		$templateInstance = XmlTemplateEngineFactory::createXmlTemplateEngineInstance('node_request_node_list_answer_template_class');

		// Set it for later use
		$this->setTemplateInstance($templateInstance);

		// Read the XML descriptor
		$templateInstance->loadXmlTemplate();

		// "Cache" entries instance for next foreach loop
		$entriesInstance = $templateInstance->getTemplateInstance();

		// Is must not be NULL (then it can only be a template instance)
		assert(!is_null($entriesInstance));

		// Render the XML content
		$templateInstance->renderXmlContent();
	}

	/**
	 * Send out request-node-list answer package
	 *
	 * @param	$nodeInstance	An instance of a NodeHelper class
	 * @return	void
	 */
	public function sendPackage (NodeHelper $nodeInstance) {
		// Sanity check: Is the node in the approx. state? (active/reachable)
		$nodeInstance->getStateInstance()->validateNodeStateIsActiveOrReachable();

		// Compile the template, this inserts the loaded node data into the gaps.
		$this->getTemplateInstance()->compileTemplate();

		// Get a singleton network package instance
		$packageInstance = NetworkPackageFactory::createNetworkPackageInstance();

		// Next, feed the content in. The network package class is a pipe-through class.
		$packageInstance->enqueueRawDataFromTemplate($this);
	}
}

// [EOF]
?>
